#
# spec file for package iml
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without openblas

Name:           iml
%define lname   libiml0
Version:        1.0.5
Release:        5.12
Summary:        An Integer Matrix Library
License:        BSD-3-Clause
Group:          Productivity/Scientific/Math
URL:            https://cs.uwaterloo.ca/~astorjoh/iml.html

Source:         https://www.cs.uwaterloo.ca/~astorjoh/%name-%version.tar.bz2
BuildRequires:  gmp-devel >= 3.1.1
%if %{with openblas}
BuildRequires:  openblas-devel
%else
BuildRequires:  blas-devel
BuildRequires:  cblas-devel
%endif

%description
IML package provides routines to solve nonsingular systems of linear
equations, solve any shape systems of linear equations, and perform
mod p matrix operations, such as computing row-echelon form,
determinant, rank profile, inverse of a mod p matrix.

%package -n %lname
Summary:        An Integer Matrix Library
Group:          System/Libraries

%description -n %lname
IML package provides routines to solve nonsingular systems of linear
equations, solve any shape systems of linear equations, and perform
mod p matrix operations, such as computing row-echelon form,
determinant, rank profile, inverse of a mod p matrix.

%package devel
Summary:        Development files for IML, an Integer Matrix Library
Group:          Development/Libraries/C and C++
Requires:       %lname = %version
Requires:       gmp-devel >= 3.3.1

%description devel
IML package provides routines to solve nonsingular systems of linear
equations, solve any shape systems of linear equations, and perform
mod p matrix operations, such as computing row-echelon form,
determinant, rank profile, inverse of a mod p matrix.

This subpackage contains the include files and library links for   
developing against the IML library.

%prep
%autosetup -p1

%build
%configure --enable-shared --disable-static \
%if %{with openblas}
	   --with-cblas="-lopenblas" \
%else
	   --with-cblas="-lcblas -lblas" \
%endif
	   %nil
%make_build

%check
%make_build check

%install
b="%buildroot"
%make_install
rm -f "$b/%_libdir"/*.la
mkdir -p "$b/%_docdir"
mv "$b/%_datadir/iml" "$b/%_docdir/"

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%_libdir/libiml.so.0*
%license COPYING

%files devel
%_includedir/iml.h
%_libdir/libiml.so
%_docdir/%name/

%changelog
* Thu Dec 24 2020 Jan Engelhardt <jengelh@inai.de>
- Specfile modernization.
* Sat Aug 24 2019 Jan Engelhardt <jengelh@inai.de>
- Specfile modernization.
* Wed Aug 15 2018 schwab@suse.de
- Add option to build without openblas
* Sat Sep  9 2017 jengelh@inai.de
- For the BLAS implementation, switch from cblas to openblas.
* Mon May 30 2016 jengelh@inai.de
- Switch from ATLAS to CBLAS
* Sun Mar 13 2016 jengelh@inai.de
- Update to new upstream release 1.0.5
  * This version incorporates a new functions kernelLong and kernelMP
  into the library interface for computing a right kernel basis of
  an integer matrix of type long and filled with GMP bignums,
  respectively. The kernel basis returned can be optionally reduced
  using lattice basis reduction. Unlike functions nullspaceLong and
  nullspaceMP which only compute a basis for the rational nullspace,
  functions kernelLong and kernelMP produce an integer basis for
  the sublattice of all integer vectors in the right kernel of the
  input matrix.
* Tue Jun  9 2015 jengelh@inai.de
- Use openSUSE's new ATLAS include path
- Upstream has replaced the 1.0.4 tarball with a same-named update
  which includes a new file, cblas.h. (We do not seem to use it
  anyway, because of ATLAS.)
* Sat Aug  9 2014 jengelh@inai.de
- Update to new upstream release 1.0.4
  * fix some memleaks in nullspace.c
  * support CBLAS implementation other than ATLAS
* Thu May 23 2013 dmitry_r@opensuse.org
- Replace tarball by the original variant
* Sun May 19 2013 jengelh@inai.de
- Initial package (version 1.0.3) for build.opensuse.org
